@@ -1,22 +1,8 @@
 /*
- * Copyright 2020 Kai Uwe Broulik <kde@broulik.de>
- * Copyright 2021 David Redondo <kde@david-redondo.de>
+ * SPDX-FileCopyrightText: 2020 Kai Uwe Broulik <kde@broulik.de>
+ * SPDX-FileCopyrightText: 2021 David Redondo <kde@david-redondo.de>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "powerprofile.h"
@@ -25,9 +11,9 @@
 #include "powerprofileadaptor.h"
 #include "properties_interface.h"
 
+#include <PowerDevilProfileSettings.h>
 #include <powerdevil_debug.h>
 
-#include <KConfigGroup>
 #include <KPluginFactory>
 
 using namespace PowerDevil::BundledActions;
@@ -43,7 +29,7 @@ static const QString profileHoldsProperty = QStringLiteral("ActiveProfileHolds")
 static const QString ppdName = QStringLiteral("net.hadess.PowerProfiles");
 static const QString ppdPath = QStringLiteral("/net/hadess/PowerProfiles");
 
-PowerProfile::PowerProfile(QObject *parent, const QVariantList &)
+PowerProfile::PowerProfile(QObject *parent)
     : Action(parent)
     , m_powerProfilesInterface(new NetHadessPowerProfilesInterface(ppdName, ppdPath, QDBusConnection::systemBus(), this))
     , m_powerProfilesPropertiesInterface(new OrgFreedesktopDBusPropertiesInterface(ppdName, ppdPath, QDBusConnection::systemBus(), this))
@@ -53,7 +39,7 @@ PowerProfile::PowerProfile(QObject *parent, const QVariantList &)
 
     connect(m_holdWatcher, &QDBusServiceWatcher::serviceUnregistered, this, &PowerProfile::serviceUnregistered);
     connect(m_powerProfilesPropertiesInterface, &OrgFreedesktopDBusPropertiesInterface::PropertiesChanged, this, &PowerProfile::propertiesChanged);
-    connect(m_powerProfilesInterface, &NetHadessPowerProfilesInterface::ProfileReleased, this, [this] (unsigned int cookie) {
+    connect(m_powerProfilesInterface, &NetHadessPowerProfilesInterface::ProfileReleased, this, [this](unsigned int cookie) {
         auto it = std::find(m_holdMap.begin(), m_holdMap.end(), cookie);
         if (it != m_holdMap.end()) {
             if (m_holdMap.count(it.key()) == 1) {
@@ -77,38 +63,22 @@ PowerProfile::PowerProfile(QObject *parent, const QVariantList &)
 
 PowerProfile::~PowerProfile() = default;
 
-void PowerProfile::onProfileLoad()
+void PowerProfile::onProfileLoad(const QString & /*previousProfile*/, const QString & /*newProfile*/)
 {
     if (!m_configuredProfile.isEmpty()) {
         setProfile(m_configuredProfile);
     }
 }
 
-void PowerProfile::onWakeupFromIdle()
-{
-}
-
-void PowerProfile::onIdleTimeout(int msec)
-{
-    Q_UNUSED(msec);
-}
-
-void PowerProfile::onProfileUnload()
-{
-}
-
 void PowerProfile::triggerImpl(const QVariantMap &args)
 {
     Q_UNUSED(args);
 }
 
-bool PowerProfile::loadAction(const KConfigGroup &config)
+bool PowerProfile::loadAction(const PowerDevil::ProfileSettings &profileSettings)
 {
-    if (config.hasKey("profile")) {
-        m_configuredProfile = config.readEntry("profile", QString());
-    }
-
-    return true;
+    m_configuredProfile = profileSettings.powerProfile();
+    return !m_configuredProfile.isEmpty();
 }
 
 bool PowerProfile::isSupported()
@@ -159,7 +129,7 @@ void PowerProfile::setProfile(const QString &profile)
     }
 }
 
-unsigned int PowerProfile::holdProfile(const QString& profile, const QString& reason, const QString& applicationId)
+unsigned int PowerProfile::holdProfile(const QString &profile, const QString &reason, const QString &applicationId)
 {
     if (!m_profileChoices.contains(profile)) {
         sendErrorReply(QDBusError::InvalidArgs, QStringLiteral("%1 is not a valid profile").arg(profile));
@@ -232,7 +202,6 @@ void PowerProfile::readProperties(const QVariantMap &properties)
         Q_EMIT profileChoicesChanged(m_profileChoices);
     }
 
-
     if (properties.contains(performanceInhibitedProperty)) {
         m_performanceInhibitedReason = properties[performanceInhibitedProperty].toString();
         Q_EMIT performanceInhibitedReasonChanged(m_performanceInhibitedReason);
@@ -259,3 +228,5 @@ void PowerProfile::propertiesChanged(const QString &interface, const QVariantMap
 }
 
 #include "powerprofile.moc"
+
+#include "moc_powerprofile.cpp"
