@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2014 by Nikita Skovoroda <chalkerx@gmail.com>            *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2014 Nikita Skovoroda <chalkerx@gmail.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "powerdevilscreenbrightnesslogic.h"
 #include "powerdevil_debug.h"
@@ -23,13 +10,18 @@
 
 namespace PowerDevil
 {
-
 int ScreenBrightnessLogic::toggled() const
 {
     // ignore, we won't toggle the display off
     return -1;
 }
 
+int ScreenBrightnessLogic::valueMin() const
+{
+    // 0 can turn off the backlight with some drivers
+    return 1;
+}
+
 int ScreenBrightnessLogic::calculateSteps(int maxValue) const
 {
     // We assume that the preferred number of steps for screen brightness is 20, but we don't want more.
